"use strict";

var _plugin = require("../plugin");

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

describe('stylisPluginCssVariables', function () {
  beforeEach(function () {
    // Clear root HTML node styles
    document.documentElement.style = null;
  });
  /* eslint-disable */

  var baseArgs = {
    context: 2,
    content: '',
    selectors: ['.font'],
    parents: [],
    line: 80,
    column: 2,
    length: 10,
    type: 105
  };
  /* eslint-enable */
  // in JSDOM, `window.CSS` is undefined (at least in the environment used here)
  // so we don't need to process supported browsers

  var createPlugin = function () {
    return (0, _plugin.stylisPluginCssVariables)();
  };

  test('should return undefined if no fallbacks are available', function () {
    var plugin = createPlugin();

    var args = _objectSpread({}, baseArgs);

    args.content = 'font-size: 14px';
    var result = plugin.apply(void 0, Object.values(args));
    expect(result).toBe(undefined);
  });
  test('should return fallback declaration and variablized declaration if var() is used and fallbacks are available', function () {
    var plugin = createPlugin();

    var args = _objectSpread({}, baseArgs);

    args.content = ['font-size: var( --font, 14px );'].join('');
    var result = plugin.apply(void 0, Object.values(args));
    expect(result).toBe(['font-size:14px;', 'font-size: var( --font, 14px );'].join(''));
  });
  test('should handle declarations with parentheses values', function () {
    var plugin = createPlugin();

    var args = _objectSpread({}, baseArgs);

    args.content = ['font-size: var( --font, 14px );', 'filter: var( --blur, blur(20px) );', 'transform: translate3d(0, 0, 0);'].join('');
    var result = plugin.apply(void 0, Object.values(args));
    expect(result).toBe(['font-size:14px;', 'font-size: var( --font, 14px );', 'filter:blur(20px);', 'filter: var( --blur, blur(20px) );', 'transform: translate3d(0, 0, 0);'].join(''));
  });
  test('should return fallback declarations for every var() call', function () {
    // Set :root variables
    document.documentElement.style.setProperty('--bg', 'black');
    document.documentElement.style.setProperty('--height', '30px');
    document.documentElement.style.setProperty('--size', '2');
    var plugin = createPlugin();

    var args = _objectSpread({}, baseArgs);

    args.content = ['background: var( --bg );', 'font-size: var( --font, 14px );', 'height: calc((var(--height, 20px) * 1.2));', 'transform: translate( var(--x, 0) , 0) scale( var(--size, 1) );', 'z-index: var( --z, var( --z2, 2) );'].join('');
    var result = plugin.apply(void 0, Object.values(args));
    expect(result).toBe(['background:black;', 'background: var( --bg );', 'font-size:14px;', 'font-size: var( --font, 14px );', 'height:calc((30px * 1.2));', 'height: calc((var(--height, 20px) * 1.2));', 'transform:translate( 0 , 0) scale( 2);', 'transform: translate( var(--x, 0) , 0) scale( var(--size, 1) );', 'z-index:2;', 'z-index: var( --z, var( --z2, 2) );'].join(''));
  });
  test('should return if a single fallback was transformed out of many', function () {
    var plugin = createPlugin();

    var args = _objectSpread({}, baseArgs);

    args.content = ['background: var( --bg );', 'font-size: var( --font, 14px );', 'z-index: var( --z );'].join('');
    var result = plugin.apply(void 0, Object.values(args));
    expect(result).toBe(['background: var( --bg );', 'font-size:14px;', 'font-size: var( --font, 14px );', 'z-index: var( --z );'].join(''));
  });
  test('it should skip when the browser is supported', function () {
    // reset the module registry
    jest.resetModules(); // actually make JSDOM look like it supports CSS vars (it doesn't by default)

    window.CSS = {
      supports: jest.fn(function () {
        return true;
      })
    }; // re-require the plugin to re-run the side-effect-y `isNativeSupport`

    var _require = require('../plugin'),
        pluginFactory = _require.stylisPluginCssVariables; // create the plugin w/ the factory from the re-required


    var plugin = pluginFactory();

    var args = _objectSpread({}, baseArgs);

    args.content = ['font-size: var( --font, 14px );'].join('');
    var result = plugin.apply(void 0, Object.values(args));
    expect(result).toBe(undefined); // the default value for window.CSS in JSDOM

    window.CSS = undefined;
  });
  test('it should not skip supported browsers when skipSupportedBrowsers is false', function () {
    // reset the module registry
    jest.resetModules(); // actually make JSDOM look like it supports CSS vars (it doesn't by default)

    window.CSS = {
      supports: jest.fn(function () {
        return true;
      })
    }; // re-require the plugin to re-run the side-effect-y `isNativeSupport`

    var _require2 = require('../plugin'),
        pluginFactory = _require2.stylisPluginCssVariables; // create the plugin w/ the factory from the re-required


    var plugin = pluginFactory({
      skipSupportedBrowsers: false
    });

    var args = _objectSpread({}, baseArgs);

    args.content = ['font-size: var( --font, 14px );'].join('');
    var result = plugin.apply(void 0, Object.values(args));
    expect(result).toBe(['font-size:14px;', 'font-size: var( --font, 14px );'].join(''));
  });
});